# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: packs_grpc.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'packs_grpc.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x10packs_grpc.proto\x12\rpacks_grpc.v1\"\x1c\n\x0eIsPackExistReq\x12\n\n\x02id\x18\x01 \x01(\r\" \n\x0fIsPackExistResp\x12\r\n\x05\x65xist\x18\x01 \x01(\x08\x32W\n\x05Packs\x12N\n\x0bIsPackExist\x12\x1d.packs_grpc.v1.IsPackExistReq\x1a\x1e.packs_grpc.v1.IsPackExistResp\"\x00\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'packs_grpc_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_ISPACKEXISTREQ']._serialized_start=35
  _globals['_ISPACKEXISTREQ']._serialized_end=63
  _globals['_ISPACKEXISTRESP']._serialized_start=65
  _globals['_ISPACKEXISTRESP']._serialized_end=97
  _globals['_PACKS']._serialized_start=99
  _globals['_PACKS']._serialized_end=186
# @@protoc_insertion_point(module_scope)
